@@ -6,7 +6,7 @@
 
 //
 //    BEDOPS
-//    Copyright (C) 2011-2022 Shane Neph, Scott Kuehn and Alex Reynolds
+//    Copyright (C) 2011-2025 Shane Neph, Scott Kuehn and Alex Reynolds
 //
 //    This program is free software; you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
@@ -194,7 +194,8 @@ STARCH_gzip_deflate(FILE *source, FILE *dest, int level)
     /* deflateInit2 allows creation of archive with gzip header, i.e. a gzip file */
     /* cf. http://www.zlib.net/manual.html */
 #ifdef __cplusplus
-    ret = deflateInit2cpp(&strm, level, Z_DEFLATED, (15+16), 8, Z_DEFAULT_STRATEGY);
+    // ret = deflateInit2cpp(&strm, level, Z_DEFLATED, (15+16), 8, Z_DEFAULT_STRATEGY);
+    ret = deflateInit2(&strm, level, Z_DEFLATED, (15+16), 8, Z_DEFAULT_STRATEGY);
 #else
     ret = deflateInit2(&strm, level, Z_DEFLATED, (15+16), 8, Z_DEFAULT_STRATEGY);
 #endif
